Computes average income in each location, which is the weighted average of the income of the people living in the location.
av_income_simple(lambda_ij_i, w_tr)NxN matrix - Probability of individuals in each location of working in each location.
NxS - Wages in each location in each sector.