Function to estimate amenity parameters of locations where users live.
living_amenities_simple(theta, N, L_i, W_i, Q, K, alpha, t_ij, rho, eta)Matrix with the amenity distribution of living in each location.
Float - Parameter that governs the reallocation of workers across locations in the city. This parameter measures how sensible are migration flows within the city to changes in real income.
Integer - Number of locations.
Nx1 matrix - Total residents.
Nx1 matrix - Market access measure in each location.
Nx1 matrix - Floor space prices.
Nx1 matrix - Land area
Float - Para
NxN matrix - Travel times across locations.
Float - decay parameter for amenities.
Float - congestion force